CREATE OR REPLACE PACKAGE app_k_estadisticas IS
  --------------------------------------------------------------------------------------------------------
  --
  -- R7.1  
  -- Cuando el estado del regalo pasa a PAGADO se analiza el nmero de veces que se ha regalado a distintas personas durante ese ao y se almacena el dato en la tabla EST_ANO_REGALO.
  --
  -- CARGA EL DATO. Slo debe invocarse internamente a travs del trigger T_GRUPOS_REGALOS de la tabla GRUPOS_REGALOS
  PROCEDURE pi_set_reg_pagado_persona_ano(p_cln_regalo_in IN regalos.cln_regalo%TYPE,
                                          p_cln_grupo_in  IN grupos.cln_grupo%TYPE,
                                          p_ano_in        IN VARCHAR2);
  -- CONSULTA DEL DATO. Se puede invocar libremente.
  PROCEDURE pr_get_reg_pagado_persona_ano(p_cln_regalo_in IN regalos.cln_regalo%TYPE,
                                          p_ano_in        IN VARCHAR2,
                                          p_rsp_out       OUT NOCOPY logs.rsp%TYPE);
  --

  --------------------------------------------------------------------------------------------------------
  --
  -- R7.2
  -- Cuando el estado del regalo pasa a PAGADO se incrementa el valor almacenado en el campo num_tot_regalos de la tabla EST_ANO.
  --
  -- CARGA EL DATO. Slo debe invocarse internamente a travs del trigger T_GRUPOS_REGALOS de la tabla GRUPOS_REGALOS
  PROCEDURE pi_set_total_regalo_pagado_ano(p_ano_in IN VARCHAR2);
  -- CONSULTA DEL DATO. Se puede invocar libremente.
  PROCEDURE pr_get_total_regalo_pagado_ano(p_ano_in  IN VARCHAR2,
                                           p_rsp_out OUT NOCOPY logs.rsp%TYPE);
  --

  --------------------------------------------------------------------------------------------------------
  --
  -- R7.3
  -- Cuando el estado del regalo pasa a PAGADO se incrementa el importe almacenado en el campo sum_tot_imp_eur de la tabla EST_ANO.
  --
  -- CARGA EL DATO. Slo debe invocarse internamente a travs del trigger T_GRUPOS_REGALOS de la tabla GRUPOS_REGALOS
  PROCEDURE pi_set_total_imp_pagado_ano(p_imp_in IN est_ano.sum_tot_imp_eur%TYPE,
                                        p_ano_in IN VARCHAR2);
  -- CONSULTA DEL DATO. Se puede invocar libremente.
  PROCEDURE pr_get_total_imp_pagado_ano(p_ano_in  IN VARCHAR2,
                                        p_rsp_out OUT NOCOPY logs.rsp%TYPE);
  --

  --------------------------------------------------------------------------------------------------------
  --
  -- R7.4
  -- Cuando el estado del regalo pasa a PAGADO o a NO_SUFICIENTES_FONDOS se incrementan los contadores de los campo respectivos num_reg_alcanzados, num_reg_sinfondos de la tabla EST_ANO.
  --
  -- CARGA EL DATO. Slo debe invocarse internamente a travs del trigger T_GRUPOS_REGALOS de la tabla GRUPOS_REGALOS
  PROCEDURE pi_set_estado_pct_ano(p_cod_estado_regalo_in IN grupos_regalos.cod_estado_regalo%TYPE,
                                  p_ano_in               IN VARCHAR2);
  -- CONSULTA DEL DATO. Se puede invocar libremente.
  PROCEDURE pr_get_estado_pct_ano(p_ano_in  IN VARCHAR2,
                                  p_rsp_out OUT NOCOPY logs.rsp%TYPE);
  --

  --------------------------------------------------------------------------------------------------------
  --
  -- R7.5
  -- Cuando el estado del regalo pasa a PAGADO se recalcula el campo med_gastos_eur de la tabla EST_ANO.
  --
  -- CARGA EL DATO. Slo debe invocarse internamente a travs del trigger T_GRUPOS_REGALOS de la tabla GRUPOS_REGALOS
  PROCEDURE pi_set_med_imp_usu_ano(p_cln_regalo_in IN grupos_regalos.cln_regalo%TYPE,
                                   p_cln_grupo_in  IN grupos_regalos.cln_grupo%TYPE,
                                   p_ano_in        IN VARCHAR2);
  -- CONSULTA DEL DATO. Se puede invocar libremente.
  PROCEDURE pr_get_med_imp_usu_ano(p_ano_in  IN VARCHAR2,
                                   p_rsp_out OUT NOCOPY logs.rsp%TYPE);

  --------------------------------------------------------------------------------------------------------
  --
  -- R7.6  
  -- Cuando el estado del regalo pasa a RECIBIDO se analiza el nmero de regalos que ha recibido cada persona durante ese ao/mes y se almacena el dato en la tabla EST_ANO_MES / EST_ANO_MES_AUX_USU.
  --
  -- CARGA EL DATO. Slo debe invocarse internamente a travs del trigger T_GRUPOS_REGALOS de la tabla GRUPOS_REGALOS
  PROCEDURE pi_set_usu_mas_reg_recib_am(p_cln_grupo_in IN grupos.cln_grupo%TYPE,
                                        p_ano_in       IN VARCHAR2,
                                        p_mes_in       IN VARCHAR2);
  -- CONSULTA DEL DATO. Se puede invocar libremente.
  PROCEDURE pr_get_usu_mas_reg_recib_am(p_ano_in  IN VARCHAR2,
                                        p_mes_in  IN VARCHAR2,
                                        p_rsp_out OUT NOCOPY logs.rsp%TYPE);
  --
  --------------------------------------------------------------------------------------------------------
  --
  -- R7.7  
  -- Cuando el estado del regalo pasa a PAGADO se analiza el importe que se ha gastado en regalos esa persona durante ese ao/mes y se almacena el dato en la tabla EST_ANO_MES / EST_ANO_MES_AUX_USU.
  -- Los datos de la tabla TRANSACCIONES_ECO se dan por definitivos cuando el estado pasa a pagado ya que a partir de ese momento no se admiten devoluciones.
  --
  -- CARGA EL DATO. Slo debe invocarse internamente a travs del trigger T_GRUPOS_REGALOS de la tabla GRUPOS_REGALOS
  PROCEDURE pi_set_usu_mas_gas_realiz_am(p_cln_grupo_in  IN grupos.cln_grupo%TYPE,
                                         p_cln_regalo_in IN regalos.cln_regalo%TYPE,
                                         p_ano_in        IN VARCHAR2,
                                         p_mes_in        IN VARCHAR2);
  -- CONSULTA DEL DATO. Se puede invocar libremente.
  PROCEDURE pr_get_usu_mas_gas_realiz_am(p_ano_in  IN VARCHAR2,
                                         p_mes_in  IN VARCHAR2,
                                         p_rsp_out OUT NOCOPY logs.rsp%TYPE);
  --
  --------------------------------------------------------------------------------------------------------
  --
  -- R7.8
  -- Cuando el estado del regalo pasa a PAGADO se analiza las personas que han participado en ese regalo y se actualiza la lista si es la primera vez que participan en el regalo. Afecta a cada ao/mes y se almacena el dato en la tabla EST_ANO_MES / EST_ANO_MES_AUX_USU / EST_ANO_MES_AUX_REG.
  -- Los datos de la tabla TRANSACCIONES_ECO se dan por definitivos cuando el estado pasa a pagado ya que a partir de ese momento no se admiten devoluciones.
  --
  -- CARGA EL DATO. Slo debe invocarse internamente a travs del trigger T_GRUPOS_REGALOS de la tabla GRUPOS_REGALOS
  PROCEDURE pi_set_usu_mas_reg_dif_part_am(p_cln_grupo_in  IN grupos.cln_grupo%TYPE,
                                           p_cln_regalo_in IN regalos.cln_regalo%TYPE,
                                           p_ano_in        IN VARCHAR2,
                                           p_mes_in        IN VARCHAR2);
  -- CONSULTA DEL DATO. Se puede invocar libremente.
  PROCEDURE pr_get_usu_mas_reg_dif_part_am(p_ano_in  IN VARCHAR2,
                                           p_mes_in  IN VARCHAR2,
                                           p_rsp_out OUT NOCOPY logs.rsp%TYPE);
  --
  --
  --------------------------------------------------------------------------------------------------------
  --
  -- R7.9
  -- Cuando el estado del regalo pasa a PAGADO se toma el importe de gasto del grupo y se actualiza la lista de gasto de grupos. Afecta a cada ao/mes y se almacena el dato en la tabla EST_ANO_MES / EST_ANO_MES_AUX_GRO.
  --
  -- CARGA EL DATO. Slo debe invocarse internamente a travs del trigger T_GRUPOS_REGALOS de la tabla GRUPOS_REGALOS
  PROCEDURE pi_set_gro_mas_gas_realiz_am(p_cln_grupo_in IN grupos.cln_grupo%TYPE,
                                         p_imp_in       IN est_ano.sum_tot_imp_eur%TYPE,
                                         p_ano_in       IN VARCHAR2,
                                         p_mes_in       IN VARCHAR2);
  -- CONSULTA DEL DATO. Se puede invocar libremente.
  PROCEDURE pr_get_gro_mas_gas_realiz_am(p_ano_in  IN VARCHAR2,
                                         p_mes_in  IN VARCHAR2,
                                         p_rsp_out OUT NOCOPY logs.rsp%TYPE);
  --  
--------------------------------------------------------------------------------------------------------
--------------------------------------------------------------------------------------------------------
--------------------------------------------------------------------------------------------------------
--------------------------------------------------------------------------------------------------------
--------------------------------------------------------------------------------------------------------
--------------------------------------------------------------------------------------------------------
END app_k_estadisticas;
/
