CREATE OR REPLACE PACKAGE app_k_grupos IS
  --------------------------------------------------------------------------------------------------------
  -- [R5] A
  PROCEDURE pr_alta_grupo(p_nom_grupo_in           IN grupos.nom_grupo%TYPE,
                          p_fec_limite_fondos_in   IN grupos.fec_limite_fondos%TYPE,
                          p_fec_limite_envio_in    IN grupos.fec_limite_envio%TYPE,
                          p_swt_imp_publicos_in    IN grupos.swt_imp_publicos%TYPE,
                          p_cln_direccion_envio_in IN grupos.cln_direccion_envio%TYPE,
                          p_dedicatoria_grupo_in   IN grupos.dedicatoria_grupo%TYPE DEFAULT NULL,
                          p_rsp_out                OUT NOCOPY logs.rsp%TYPE);

  PROCEDURE pr_baja_grupo(p_cln_grupo_in IN grupos.cln_grupo%TYPE,
                          p_rsp_out      OUT NOCOPY logs.rsp%TYPE);

  --------------------------------------------------------------------------------------------------------
  -- [R5] C
  PROCEDURE pr_alta_usuario_en_grupo(p_cln_usuario_in       IN usuarios.cln_usuario%TYPE,
                                     p_cln_grupo_in         IN grupos.cln_grupo%TYPE,
                                     p_swt_homenajeado_in   IN grupos_usuarios.swt_homenajeado%TYPE,
                                     p_swt_receptor_in      IN grupos_usuarios.swt_receptor%TYPE,
                                     p_dedicatoria_personal IN grupos_usuarios.dedicatoria_personal%TYPE DEFAULT NULL,
                                     p_rsp_out              OUT NOCOPY logs.rsp%TYPE);

  PROCEDURE pr_baja_usuario_en_grupo(p_cln_usuario_in IN usuarios.cln_usuario%TYPE,
                                     p_cln_grupo_in   IN grupos.cln_grupo%TYPE,
                                     p_rsp_out        OUT NOCOPY logs.rsp%TYPE);
  --------------------------------------------------------------------------------------------------------
  -- [R5] D
  PROCEDURE pr_alta_homenajeado_en_grupo(p_cln_usuario_in IN usuarios.cln_usuario%TYPE,
                                         p_cln_grupo_in   IN grupos.cln_grupo%TYPE,
                                         p_rsp_out        OUT NOCOPY logs.rsp%TYPE);

  PROCEDURE pr_baja_homenajeado_en_grupo(p_cln_usuario_in IN usuarios.cln_usuario%TYPE,
                                         p_cln_grupo_in   IN grupos.cln_grupo%TYPE,
                                         p_rsp_out        OUT NOCOPY logs.rsp%TYPE);
  -- [R5] H
  PROCEDURE pr_alta_receptor_en_grupo(p_cln_usuario_in IN usuarios.cln_usuario%TYPE,
                                      p_cln_grupo_in   IN grupos.cln_grupo%TYPE,
                                      p_rsp_out        OUT NOCOPY logs.rsp%TYPE);

  PROCEDURE pr_baja_receptor_en_grupo(p_cln_usuario_in IN usuarios.cln_usuario%TYPE,
                                      p_cln_grupo_in   IN grupos.cln_grupo%TYPE,
                                      p_rsp_out        OUT NOCOPY logs.rsp%TYPE);
  -- [R5] B
  PROCEDURE pr_alta_regalo_en_grupo(p_cln_regalo_in IN regalos.cln_regalo%TYPE,
                                    p_cln_grupo_in  IN grupos.cln_grupo%TYPE,
                                    p_rsp_out       OUT NOCOPY logs.rsp%TYPE);

  PROCEDURE pr_baja_regalo_en_grupo(p_cln_regalo_in IN regalos.cln_regalo%TYPE,
                                    p_cln_grupo_in  IN grupos.cln_grupo%TYPE,
                                    p_rsp_out       OUT NOCOPY logs.rsp%TYPE);
  -- [R5] E
  PROCEDURE pr_alta_aportacion_a_grupo(p_cln_usuario_in        IN usuarios.cln_usuario%TYPE,
                                       p_cln_grupo_in          IN grupos.cln_grupo%TYPE,
                                       p_cln_regalo_in         IN regalos.cln_regalo%TYPE,
                                       p_cod_modalidad_pago_in IN transacciones_eco.cod_modalidad_pago%TYPE,
                                       p_detalle_pago_in       IN transacciones_eco.detalle_pago%TYPE,
                                       p_imp_in                IN transacciones_eco.imp%TYPE,
                                       p_fec_valor_in          transacciones_eco.fec_valor%TYPE,
                                       p_rsp_out               OUT NOCOPY logs.rsp%TYPE);

  PROCEDURE pr_baja_aportacion_a_grupo(p_cln_usuario_in        IN usuarios.cln_usuario%TYPE,
                                       p_cln_grupo_in          IN grupos.cln_grupo%TYPE,
                                       p_cln_regalo_in         IN regalos.cln_regalo%TYPE,
                                       p_cod_modalidad_pago_in IN transacciones_eco.cod_modalidad_pago%TYPE,
                                       p_detalle_pago_in       IN transacciones_eco.detalle_pago%TYPE,
                                       p_fec_valor_in          transacciones_eco.fec_valor%TYPE,
                                       p_rsp_out               OUT NOCOPY logs.rsp%TYPE);
  -- -- -- -- -- --
  FUNCTION f_get_usuario(p_cln_usuario_in       IN usuarios.cln_usuario%TYPE DEFAULT NULL,
                         p_email_in             IN usuarios.email%TYPE DEFAULT NULL,
                         p_devolver_borrados_in IN BOOLEAN DEFAULT FALSE) RETURN usuarios%ROWTYPE;

  FUNCTION f_get_grupo(p_cln_grupo_in         IN grupos.cln_grupo%TYPE DEFAULT NULL,
                       p_nom_grupo_in         IN grupos.nom_grupo%TYPE DEFAULT NULL,
                       p_devolver_borrados_in BOOLEAN DEFAULT FALSE) RETURN grupos%ROWTYPE;

  FUNCTION f_get_homenajeado_en_grupo_us(p_cln_grupo_in IN grupos.cln_grupo%TYPE) RETURN grupos_usuarios%ROWTYPE;

  FUNCTION f_get_receptor_en_grupo_us(p_cln_grupo_in IN grupos.cln_grupo%TYPE) RETURN grupos_usuarios%ROWTYPE;

  FUNCTION f_get_grupo_regalo(p_cln_regalo_in IN regalos.cln_regalo%TYPE,
                              p_cln_grupo_in  IN grupos.cln_grupo%TYPE) RETURN grupos_regalos%ROWTYPE;

  FUNCTION f_get_direccion_envio(p_cln_direccion_envio_in IN direcciones_envio.cln_direccion_envio%TYPE,
                                 p_devolver_borrados_in   IN BOOLEAN DEFAULT NULL) RETURN direcciones_envio%ROWTYPE;

  FUNCTION f_get_aportacion_usuario_a_grr(p_cln_usuario_in IN usuarios.cln_usuario%TYPE,
                                          p_cln_grupo_in   IN grupos.cln_grupo%TYPE,
                                          p_cln_regalo_in  IN regalos.cln_regalo%TYPE) RETURN transacciones_eco%ROWTYPE;

  --------------------------------------------------------------------------------------------------------
  --------------------------------------------------------------------------------------------------------
  --------------------------------------------------------------------------------------------------------
  --------------------------------------------------------------------------------------------------------
  --------------------------------------------------------------------------------------------------------

  FUNCTION fi_get_grupo_usuario(p_cln_usuario_in       IN usuarios.cln_usuario%TYPE,
                                p_cln_grupo_in         IN grupos.cln_grupo%TYPE,
                                p_devolver_borrados_in IN BOOLEAN DEFAULT FALSE) RETURN grupos_usuarios%ROWTYPE;

END app_k_grupos;
/
