CREATE OR REPLACE TRIGGER t_grupos_regalos
  FOR UPDATE OF cod_estado_regalo ON grupos_regalos
  COMPOUND TRIGGER

  -- variables log
  c_modulo       logs.modulo%TYPE DEFAULT upper($$PLSQL_UNIT || '.t_grupos_regalos');
  c_entrada      logs.p_entrada%TYPE DEFAULT '';
  c_error_modulo logs.rsp%TYPE := 'ERROR TRIGGER GRR. ERR ';
  v_rsp          logs.rsp%TYPE;
  --

  --Executed before each row change- :NEW, :OLD are available
  BEFORE EACH ROW IS
  BEGIN
    app_k_log.set_traza(p_modulo_in  => c_modulo,
                        p_mensaje_in => 'TRIGGER BEFORE EACH ROW  (AL PRINCIPIO) :new.cod_estado_regalo .' || :new.cod_estado_regalo ||
                                        '.  :old.cod_estado_regalo .' || :old.cod_estado_regalo || '.');
  
    --- de momento permitimos el retroceso a cualquier cdigo anterior.
    IF :new.cod_estado_regalo > :old.cod_estado_regalo THEN
      -- si retrocedemos a un cdigo anterior al que corresponden las fechas de pagado/enviado se eliminan estas fechas
      IF :new.fec_pagado IS NOT NULL AND :new.cod_estado_regalo < app_k_global.vg_c_codregalo_pagado THEN
        :new.fec_pagado := NULL;
      END IF;
      IF :new.fec_envio_regalo IS NOT NULL AND :new.cod_estado_regalo < app_k_global.vg_c_codregalo_enviado THEN
        :new.fec_envio_regalo := NULL;
      END IF;
    END IF;
  
    -- asigna automticamente las fechas PAGADO y ENVIADO
    app_k_log.set_traza(p_modulo_in  => c_modulo,
                        p_mensaje_in => 'TRIGGER BEFORE EACH ROW :new.cod_estado_regalo .' || :new.cod_estado_regalo ||
                                        '.  :old.cod_estado_regalo .' || :old.cod_estado_regalo || '.');
    app_k_log.set_traza(p_modulo_in  => c_modulo,
                        p_mensaje_in => 'TRIGGER BEFORE EACH ROW :new.imp_recaudado_eur .' || :new.imp_recaudado_eur ||
                                        '.  :old..imp_recaudado_eur .' || :old.imp_recaudado_eur || '.');
  
    IF :new.cod_estado_regalo = app_k_global.vg_c_codregalo_pagado THEN
      app_k_log.set_traza(p_modulo_in => c_modulo, p_mensaje_in => 'TRIGGER BEFORE EACH ROW aaaa');
    END IF;
    IF :new.cod_estado_regalo <> :old.cod_estado_regalo THEN
      app_k_log.set_traza(p_modulo_in => c_modulo, p_mensaje_in => 'TRIGGER BEFORE EACH ROW bbbb');
    END IF;
  
    IF :new.cod_estado_regalo = app_k_global.vg_c_codregalo_pagado AND :new.cod_estado_regalo <> :old.cod_estado_regalo THEN
      -- cod 3
      :new.fec_pagado := SYSDATE;
      app_k_log.set_traza(p_modulo_in => c_modulo, p_mensaje_in => 'TRIGGER BEFORE EACH ROW :new.fec_pagado ' || :new.fec_pagado);
    END IF;
    IF :new.cod_estado_regalo = app_k_global.vg_c_codregalo_enviado AND :new.cod_estado_regalo <> :old.cod_estado_regalo THEN
      -- cod 5
      :new.fec_envio_regalo := SYSDATE;
    END IF;
  EXCEPTION
    WHEN OTHERS THEN
      v_rsp := c_error_modulo || SQLCODE || ' ' || SQLERRM;
      app_k_log.set_traza_y_log(p_modulo_in => c_modulo, p_entrada_in => c_entrada, p_salida_in => 'ERROR', p_rsp_in => v_rsp);
      RAISE;
  END BEFORE EACH ROW;

  AFTER EACH ROW IS
  BEGIN
  
    IF :new.cod_estado_regalo <> :old.cod_estado_regalo THEN
      CASE
        WHEN :new.cod_estado_regalo = app_k_global.vg_c_codregalo_pagado THEN
          app_k_log.set_traza(p_modulo_in => c_modulo, p_mensaje_in => 'TRIGGER vg_c_codregalo_pagado');
        
          -- Actualiza para RF7.1
          app_k_log.set_traza(p_modulo_in => c_modulo, p_mensaje_in => 'TRIGGER AFTER EACH ROW :new.fec_pagado ' || :new.fec_pagado);
          app_k_estadisticas.pi_set_reg_pagado_persona_ano(p_cln_regalo_in => :new.cln_regalo,
                                                           p_cln_grupo_in  => :new.cln_grupo,
                                                           p_ano_in        => to_char(:new.fec_pagado, 'yyyy'));
          -- Actualiza para RF7.2
          app_k_estadisticas.pi_set_total_regalo_pagado_ano(p_ano_in => to_char(:new.fec_pagado, 'yyyy'));
          -- Actualiza para RF7.3
          app_k_estadisticas.pi_set_total_imp_pagado_ano(p_imp_in => :new.imp_recaudado_eur, p_ano_in => to_char(:new.fec_pagado, 'yyyy'));
        
          -- Actualiza para RF7.4a, 4
          app_k_estadisticas.pi_set_estado_pct_ano(p_cod_estado_regalo_in => :new.cod_estado_regalo,
                                                   p_ano_in               => to_char(:new.fec_pagado, 'yyyy'));
        
          -- Actualiza para RF7.5a, 7.5b, 5
          app_k_estadisticas.pi_set_med_imp_usu_ano(p_cln_regalo_in => :new.cln_regalo,
                                                    p_cln_grupo_in  => :new.cln_grupo,
                                                    p_ano_in        => to_char(:new.fec_pagado, 'yyyy'));
        
          -- Actualiza para RF7.7
          app_k_estadisticas.pi_set_usu_mas_gas_realiz_am(p_cln_grupo_in  => :new.cln_grupo,
                                                          p_cln_regalo_in => :new.cln_regalo,
                                                          p_ano_in        => to_char(:new.fec_pagado, 'yyyy'),
                                                          p_mes_in        => to_char(:new.fec_pagado, 'mm'));
        
          -- Actualiza para RF7.8
          app_k_estadisticas.pi_set_usu_mas_reg_dif_part_am(p_cln_grupo_in  => :new.cln_grupo,
                                                            p_cln_regalo_in => :new.cln_regalo,
                                                            p_ano_in        => to_char(:new.fec_pagado, 'yyyy'),
                                                            p_mes_in        => to_char(:new.fec_pagado, 'mm'));
        
          -- Actualiza para RF7.9
          app_k_estadisticas.pi_set_gro_mas_gas_realiz_am(p_cln_grupo_in => :new.cln_grupo,
                                                          p_imp_in       => :new.imp_recaudado_eur,
                                                          p_ano_in       => to_char(:new.fec_pagado, 'yyyy'),
                                                          p_mes_in       => to_char(:new.fec_pagado, 'mm'));
        
        WHEN :new.cod_estado_regalo = app_k_global.vg_c_codregalo_no_sufic_fondos THEN
          -- Actualiza para RF7.4b, 4
          app_k_estadisticas.pi_set_estado_pct_ano(p_cod_estado_regalo_in => :new.cod_estado_regalo, p_ano_in => to_char(SYSDATE, 'yyyy'));
        
        WHEN :new.cod_estado_regalo = app_k_global.vg_c_codregalo_recibido THEN
          -- Actualiza para RF7.6
          app_k_estadisticas.pi_set_usu_mas_reg_recib_am(p_cln_grupo_in => :new.cln_grupo,
                                                         p_ano_in       => to_char(:new.fec_pagado, 'yyyy'),
                                                         p_mes_in       => to_char(:new.fec_pagado, 'mm'));
        ELSE
          app_k_log.set_traza(p_modulo_in => c_modulo, p_mensaje_in => 'TRIGGER else');
      END CASE;
    END IF;
  EXCEPTION
    WHEN OTHERS THEN
      v_rsp := c_error_modulo || SQLCODE || ' ' || SQLERRM;
      app_k_log.set_traza_y_log(p_modulo_in => c_modulo, p_entrada_in => c_entrada, p_salida_in => 'ERROR', p_rsp_in => v_rsp);
      RAISE;
  END AFTER EACH ROW;
END t_grupos_regalos;
/
